var name = "create-typescript-app";
var version = "2.44.6";
var description = "Quickstart-friendly TypeScript template with comprehensive, configurable, opinionated tooling. 🎁";
var repository = {
	type: "git",
	url: "git+https://github.com/JoshuaKGoldberg/create-typescript-app.git"
};
var license = "MIT";
var author = {
	name: "Josh Goldberg ✨",
	email: "npm@joshuakgoldberg.com"
};
var type = "module";
var main = "lib/index.js";
var bin = "bin/index.js";
var files = [
	"LICENSE.md",
	"README.md",
	"bin/index.js",
	"lib/",
	"package.json"
];
var scripts = {
	build: "tsup",
	format: "prettier .",
	lint: "eslint . --max-warnings 0",
	"lint:knip": "knip",
	"lint:md": "markdownlint \"**/*.md\" \".github/**/*.md\" --rules sentences-per-line",
	"lint:packages": "pnpm dedupe --check",
	"lint:spelling": "cspell \"**\" \".github/**/*\"",
	prepare: "husky",
	test: "vitest",
	tsc: "tsc"
};
var dependencies = {
	"@typescript-eslint/typescript-estree": "^8.35.0",
	bingo: "^0.5.16",
	"bingo-fs": "^0.5.5",
	"bingo-stratum": "^0.5.11",
	"cached-factory": "^0.1.0",
	"cspell-populate-words": "^0.3.1",
	execa: "^9.6.0",
	"git-url-parse": "^16.1.0",
	"github-default-labels": "^0.1.1",
	"html-to-text": "^9.0.5",
	"image-size": "^2.0.2",
	"input-from-file": "^0.5.4",
	"input-from-file-json": "^0.5.4",
	"input-from-script": "^0.5.4",
	"js-yaml": "^4.1.0",
	json5: "^2.2.3",
	"lazy-value": "^3.0.0",
	lodash: "^4.17.21",
	marked: "^15.0.12",
	"npm-user": "^6.1.1",
	"object-strings-deep": "^0.1.2",
	"parse-author": "^2.0.0",
	"parse-package-name": "^1.0.0",
	"remove-dependencies": "^0.1.1",
	"remove-undefined-objects": "^6.0.0",
	semver: "^7.7.2",
	"set-github-repository-labels": "^0.2.2",
	"sort-keys": "^5.1.0",
	"sort-package-json": "^3.3.1",
	"title-case": "^4.3.2",
	"trash-cli": "^6.0.0",
	zod: "^3.25.67",
	"zod-package-json": "^1.2.0",
	"zod-tsconfig": "^0.2.0"
};
var devDependencies = {
	"@eslint-community/eslint-plugin-eslint-comments": "4.5.0",
	"@eslint/js": "9.29.0",
	"@prettier/sync": "0.6.1",
	"@release-it/conventional-changelog": "10.0.1",
	"@types/eslint-plugin-markdown": "2.0.2",
	"@types/html-to-text": "9.0.4",
	"@types/js-yaml": "4.0.9",
	"@types/lodash": "4.17.19",
	"@types/node": "24.0.4",
	"@types/parse-author": "2.0.3",
	"@types/semver": "7.7.0",
	"@vitest/coverage-v8": "3.2.4",
	"@vitest/eslint-plugin": "1.2.7",
	"all-contributors-cli": "6.26.1",
	"bingo-requests": "0.5.5",
	"bingo-stratum-testers": "0.5.9",
	"bingo-testers": "0.5.7",
	"console-fail-test": "0.5.0",
	cspell: "9.1.2",
	eslint: "9.29.0",
	"eslint-plugin-jsdoc": "51.2.3",
	"eslint-plugin-jsonc": "2.20.1",
	"eslint-plugin-markdown": "5.1.0",
	"eslint-plugin-n": "17.20.0",
	"eslint-plugin-package-json": "0.42.0",
	"eslint-plugin-perfectionist": "4.15.0",
	"eslint-plugin-regexp": "2.9.0",
	"eslint-plugin-yml": "1.18.0",
	husky: "9.1.7",
	knip: "5.61.2",
	"lint-staged": "16.1.2",
	lodash: "4.17.21",
	markdownlint: "0.38.0",
	"markdownlint-cli": "0.45.0",
	prettier: "3.6.1",
	"prettier-plugin-curly": "0.3.2",
	"prettier-plugin-packagejson": "2.5.15",
	"prettier-plugin-sh": "0.17.4",
	"release-it": "19.0.3",
	"sentences-per-line": "0.3.0",
	tsup: "8.5.0",
	typescript: "5.8.3",
	"typescript-eslint": "8.35.0",
	vitest: "3.2.4"
};
var packageManager = "pnpm@10.12.3";
var engines = {
	node: ">=20.19.0"
};
var publishConfig = {
	provenance: true
};
var _package = {
	name: name,
	version: version,
	description: description,
	repository: repository,
	license: license,
	author: author,
	type: type,
	main: main,
	bin: bin,
	files: files,
	scripts: scripts,
	"lint-staged": {
	"*": "prettier --ignore-unknown --write"
},
	dependencies: dependencies,
	devDependencies: devDependencies,
	packageManager: packageManager,
	engines: engines,
	publishConfig: publishConfig
};

declare const ______package_json_author: typeof author;
declare const ______package_json_bin: typeof bin;
declare const ______package_json_dependencies: typeof dependencies;
declare const ______package_json_description: typeof description;
declare const ______package_json_devDependencies: typeof devDependencies;
declare const ______package_json_engines: typeof engines;
declare const ______package_json_files: typeof files;
declare const ______package_json_license: typeof license;
declare const ______package_json_main: typeof main;
declare const ______package_json_name: typeof name;
declare const ______package_json_packageManager: typeof packageManager;
declare const ______package_json_publishConfig: typeof publishConfig;
declare const ______package_json_repository: typeof repository;
declare const ______package_json_scripts: typeof scripts;
declare const ______package_json_type: typeof type;
declare const ______package_json_version: typeof version;
declare namespace ______package_json {
  export { ______package_json_author as author, ______package_json_bin as bin, _package as default, ______package_json_dependencies as dependencies, ______package_json_description as description, ______package_json_devDependencies as devDependencies, ______package_json_engines as engines, ______package_json_files as files, ______package_json_license as license, ______package_json_main as main, ______package_json_name as name, ______package_json_packageManager as packageManager, ______package_json_publishConfig as publishConfig, ______package_json_repository as repository, ______package_json_scripts as scripts, ______package_json_type as type, ______package_json_version as version };
}

declare const packageData: typeof ______package_json;
declare function getPackageDependencies(...names: string[]): {
    [k: string]: string;
};
declare function getPackageDependency(name: string): string;

export { getPackageDependencies, getPackageDependency, packageData };
